@@ -1,5 +1,5 @@
 # -*- coding: utf8 -*-
-# Copyright (c) 2017-2021 THL A29 Limited, a Tencent company. All Rights Reserved.
+# Copyright (c) 2017-2025 Tencent. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -29,12 +29,18 @@ FAILEDOPERATION_ACCOUNTALREADYEXISTS = 'FailedOperation.AccountAlreadyExists'
 # 账号为当前用户
 FAILEDOPERATION_ACCOUNTISYOURSELF = 'FailedOperation.AccountIsYourSelf'
 
+# 该实例 `ins-xxxxxxx` 已经在 `dgroup-xxxxxx` 置放群组里。
+FAILEDOPERATION_ALREADYINDISASTERRECOVERGROUP = 'FailedOperation.AlreadyInDisasterRecoverGroup'
+
 # 自带许可镜像暂时不支持共享。
 FAILEDOPERATION_BYOLIMAGESHAREFAILED = 'FailedOperation.BYOLImageShareFailed'
 
 # 未找到指定的容灾组
 FAILEDOPERATION_DISASTERRECOVERGROUPNOTFOUND = 'FailedOperation.DisasterRecoverGroupNotFound'
 
+# 获取实例的自动化助手状态失败
+FAILEDOPERATION_GETINSTANCETATAGENTSTATUSFAILED = 'FailedOperation.GetInstanceTATAgentStatusFailed'
+
 # 标签键存在不合法字符
 FAILEDOPERATION_ILLEGALTAGKEY = 'FailedOperation.IllegalTagKey'
 
@@ -56,6 +62,9 @@ FAILEDOPERATION_INVALIDINSTANCEAPPLICATIONROLE = 'FailedOperation.InvalidInstanc
 # 请求不支持`EMR`的实例`ins-xxxxxxxx`。
 FAILEDOPERATION_INVALIDINSTANCEAPPLICATIONROLEEMR = 'FailedOperation.InvalidInstanceApplicationRoleEmr'
 
+# 该实例已存在指定的定时任务
+FAILEDOPERATION_MUTACTIONTIMEREXIST = 'FailedOperation.MutActionTimerExist'
+
 # 子网可用IP已耗尽。
 FAILEDOPERATION_NOAVAILABLEIPADDRESSCOUNTINSUBNET = 'FailedOperation.NoAvailableIpAddressCountInSubnet'
 
@@ -134,7 +143,7 @@ INVALIDCLIENTTOKEN_TOOLONG = 'InvalidClientToken.TooLong'
 # 无效的过滤器。
 INVALIDFILTER = 'InvalidFilter'
 
-# [`Filter`](/document/api/213/15753#Filter)。
+# [`Filter`](/document/api/213/15753#Filter)传值超出限制。
 INVALIDFILTERVALUE_LIMITEXCEEDED = 'InvalidFilterValue.LimitExceeded'
 
 # 不支持该宿主机实例执行指定的操作。
@@ -218,6 +227,9 @@ INVALIDPARAMETER = 'InvalidParameter'
 # 最多指定一个参数。
 INVALIDPARAMETER_ATMOSTONE = 'InvalidParameter.AtMostOne'
 
+# 不支持自动制作快照。
+INVALIDPARAMETER_AUTOSNAPSHOTNOTSUPPORTED = 'InvalidParameter.AutoSnapshotNotSupported'
+
 # 不支持参数CdcId。
 INVALIDPARAMETER_CDCNOTSUPPORTED = 'InvalidParameter.CdcNotSupported'
 
@@ -233,6 +245,15 @@ INVALIDPARAMETER_DUPLICATESYSTEMSNAPSHOTS = 'InvalidParameter.DuplicateSystemSna
 # 边缘可用区指定三网外网IP参数需要先指定主ip外网IP参数。
 INVALIDPARAMETER_EDGEZONEMISSINTERNETACCESSIBLE = 'InvalidParameter.EdgeZoneMissInternetAccessible'
 
+# 指定的CDH母机不支持自定义类型的子机规格
+INVALIDPARAMETER_HOSTIDCUSTOMIZEDINSTANCETYPENOTSUPPORT = 'InvalidParameter.HostIdCustomizedInstanceTypeNotSupport'
+
+# 指定的CDH母机不支持该子机机型规格
+INVALIDPARAMETER_HOSTIDINSTANCETYPENOTSUPPORT = 'InvalidParameter.HostIdInstanceTypeNotSupport'
+
+# 指定的CDH母机不支持标准类型的子机规格
+INVALIDPARAMETER_HOSTIDSTANDARDINSTANCETYPENOTSUPPORT = 'InvalidParameter.HostIdStandardInstanceTypeNotSupport'
+
 # 该主机当前状态不支持该操作。
 INVALIDPARAMETER_HOSTIDSTATUSNOTSUPPORT = 'InvalidParameter.HostIdStatusNotSupport'
 
@@ -245,6 +266,9 @@ INVALIDPARAMETER_IMAGEIDSSNAPSHOTIDSMUSTONE = 'InvalidParameter.ImageIdsSnapshot
 # 当前接口不支持实例镜像。
 INVALIDPARAMETER_INSTANCEIMAGENOTSUPPORT = 'InvalidParameter.InstanceImageNotSupport'
 
+# 不存在支持指定子机规格的CDH母机
+INVALIDPARAMETER_INSTANCETYPESUPPORTEDHOSTNOTFOUND = 'InvalidParameter.InstanceTypeSupportedHostNotFound'
+
 # 不支持设置公网带宽相关信息。
 INVALIDPARAMETER_INTERNETACCESSIBLENOTSUPPORTED = 'InvalidParameter.InternetAccessibleNotSupported'
 
@@ -260,12 +284,18 @@ INVALIDPARAMETER_INVALIDINSTANCENOTSUPPORTED = 'InvalidParameter.InvalidInstance
 # 指定的私有网络ip格式不正确。
 INVALIDPARAMETER_INVALIDIPFORMAT = 'InvalidParameter.InvalidIpFormat'
 
+# 指定的 KMS 密钥 ID 非法。
+INVALIDPARAMETER_INVALIDKMSKEYID = 'InvalidParameter.InvalidKmsKeyId'
+
 # 不能同时指定ImageIds和Filters。
 INVALIDPARAMETER_INVALIDPARAMETERCOEXISTIMAGEIDSFILTERS = 'InvalidParameter.InvalidParameterCoexistImageIdsFilters'
 
 # 错误的url地址。
 INVALIDPARAMETER_INVALIDPARAMETERURLERROR = 'InvalidParameter.InvalidParameterUrlError'
 
+# 输入的 TargetOSType 非法
+INVALIDPARAMETER_INVALIDTARGETOSTYPE = 'InvalidParameter.InvalidTargetOSType'
+
 # CoreCount和ThreadPerCore必须同时提供。
 INVALIDPARAMETER_LACKCORECOUNTORTHREADPERCORE = 'InvalidParameter.LackCoreCountOrThreadPerCore'
 
@@ -362,6 +392,12 @@ INVALIDPARAMETERVALUE_DUPLICATE = 'InvalidParameterValue.Duplicate'
 # 重复标签。
 INVALIDPARAMETERVALUE_DUPLICATETAGS = 'InvalidParameterValue.DuplicateTags'
 
+# 弹性网卡数据不存在
+INVALIDPARAMETERVALUE_ELASTICNETWORKNOTEXIST = 'InvalidParameterValue.ElasticNetworkNotExist'
+
+# 弹性网卡数据vpc子网不匹配,必须为同vpc不同子网
+INVALIDPARAMETERVALUE_ELASTICNETWORKVPCSUBNETMISMATCH = 'InvalidParameterValue.ElasticNetworkVpcSubnetMismatch'
+
 # 实例的申请的外网IP个数超过了这种规格实例的外网ip配额。
 INVALIDPARAMETERVALUE_EXTERNALIPQUOTALIMITED = 'InvalidParameterValue.ExternalIpQuotaLimited'
 
@@ -377,6 +413,9 @@ INVALIDPARAMETERVALUE_IPADDRESSMALFORMED = 'InvalidParameterValue.IPAddressMalfo
 # ipv6地址无效
 INVALIDPARAMETERVALUE_IPV6ADDRESSMALFORMED = 'InvalidParameterValue.IPv6AddressMalformed'
 
+# ISO文件必须强制导入
+INVALIDPARAMETERVALUE_ISOMUSTIMPORTBYFORCE = 'InvalidParameterValue.ISOMustImportByForce'
+
 # HostName参数值不合法
 INVALIDPARAMETERVALUE_ILLEGALHOSTNAME = 'InvalidParameterValue.IllegalHostName'
 
@@ -392,6 +431,9 @@ INVALIDPARAMETERVALUE_INSTANCENOTSUPPORTEDMIXPRICINGMODEL = 'InvalidParameterVal
 # 指定机型不存在
 INVALIDPARAMETERVALUE_INSTANCETYPENOTFOUND = 'InvalidParameterValue.InstanceTypeNotFound'
 
+# 实例类型不支持弹性网卡数据
+INVALIDPARAMETERVALUE_INSTANCETYPENOTSUPPORTELASTICNETWORKS = 'InvalidParameterValue.InstanceTypeNotSupportElasticNetworks'
+
 # 实例类型不可加入高性能计算集群。
 INVALIDPARAMETERVALUE_INSTANCETYPENOTSUPPORTHPCCLUSTER = 'InvalidParameterValue.InstanceTypeNotSupportHpcCluster'
 
@@ -419,6 +461,9 @@ INVALIDPARAMETERVALUE_INVALIDFILENAMEPREFIXLIST = 'InvalidParameterValue.Invalid
 # 不支持转为非GPU或其他类型GPU实例。
 INVALIDPARAMETERVALUE_INVALIDGPUFAMILYCHANGE = 'InvalidParameterValue.InvalidGPUFamilyChange'
 
+# 错误格式的镜像族名称
+INVALIDPARAMETERVALUE_INVALIDIMAGEFAMILY = 'InvalidParameterValue.InvalidImageFamily'
+
 # 镜像ID不支持指定的实例机型。
 INVALIDPARAMETERVALUE_INVALIDIMAGEFORGIVENINSTANCETYPE = 'InvalidParameterValue.InvalidImageForGivenInstanceType'
 
@@ -461,6 +506,9 @@ INVALIDPARAMETERVALUE_INVALIDLAUNCHTEMPLATEVERSIONDESCRIPTION = 'InvalidParamete
 # 许可证类型不可用。
 INVALIDPARAMETERVALUE_INVALIDLICENSETYPE = 'InvalidParameterValue.InvalidLicenseType'
 
+# 指定的弹性网卡id非vrdma网卡
+INVALIDPARAMETERVALUE_INVALIDNETWORKINTERFACEID = 'InvalidParameterValue.InvalidNetworkInterfaceId'
+
 # 参数值错误。
 INVALIDPARAMETERVALUE_INVALIDPARAMETERVALUELIMIT = 'InvalidParameterValue.InvalidParameterValueLimit'
 
@@ -479,6 +527,9 @@ INVALIDPARAMETERVALUE_INVALIDUSERDATAFORMAT = 'InvalidParameterValue.InvalidUser
 # 无效的模糊查询字符串。
 INVALIDPARAMETERVALUE_INVALIDVAGUENAME = 'InvalidParameterValue.InvalidVagueName'
 
+# 这个特别的VpcId or SubnetId在弹性网库数据结构未发现
+INVALIDPARAMETERVALUE_INVALIDVPCIDSUBNETIDNOTFOUND = 'InvalidParameterValue.InvalidVpcIdSubnetIdNotFound'
+
 # 边缘可用区不支持这个运营商。
 INVALIDPARAMETERVALUE_ISPNOTSUPPORTFOREDGEZONE = 'InvalidParameterValue.IspNotSupportForEdgeZone'
 
@@ -494,7 +545,7 @@ INVALIDPARAMETERVALUE_KEYPAIRNOTSUPPORTED = 'InvalidParameterValue.KeyPairNotSup
 # 不支持删除默认启动模板版本。
 INVALIDPARAMETERVALUE_LAUNCHTEMPLATEDEFAULTVERSION = 'InvalidParameterValue.LaunchTemplateDefaultVersion'
 
-# 实例启动模板ID格式错误。
+# 实例启动模板ID格式错误，请提供规范的实例启动模板ID，类似lt-xxxxxxxx，字母x代表小写字符或者数字。
 INVALIDPARAMETERVALUE_LAUNCHTEMPLATEIDMALFORMED = 'InvalidParameterValue.LaunchTemplateIdMalformed'
 
 # 实例启动模板ID不存在。
@@ -521,6 +572,9 @@ INVALIDPARAMETERVALUE_LOCALDISKSIZERANGE = 'InvalidParameterValue.LocalDiskSizeR
 # 参数值必须为开启DHCP的VPC
 INVALIDPARAMETERVALUE_MUSTDHCPENABLEDVPC = 'InvalidParameterValue.MustDhcpEnabledVpc'
 
+# 参数值必须为开启弹性rdma接口
+INVALIDPARAMETERVALUE_MUSTENABLEDISRDMA = 'InvalidParameterValue.MustEnabledIsRdma'
+
 # 子网不属于该cdc集群。
 INVALIDPARAMETERVALUE_NOTCDCSUBNET = 'InvalidParameterValue.NotCdcSubnet'
 
@@ -551,6 +605,9 @@ INVALIDPARAMETERVALUE_SNAPSHOTIDMALFORMED = 'InvalidParameterValue.SnapshotIdMal
 # 子网ID不合要求，请提供规范的子网ID，类似subnet-xxxxxxxx，字母x代表小写字符或者数字
 INVALIDPARAMETERVALUE_SUBNETIDMALFORMED = 'InvalidParameterValue.SubnetIdMalformed'
 
+# 子网ID所在可用区与实例所在区不匹配。
+INVALIDPARAMETERVALUE_SUBNETIDZONEIDNOTMATCH = 'InvalidParameterValue.SubnetIdZoneIdNotMatch'
+
 # 创建失败，您指定的子网不存在，请您重新指定
 INVALIDPARAMETERVALUE_SUBNETNOTEXIST = 'InvalidParameterValue.SubnetNotExist'
 
@@ -578,6 +635,9 @@ INVALIDPARAMETERVALUE_VPCIDMALFORMED = 'InvalidParameterValue.VpcIdMalformed'
 # 指定的VpcId不存在。
 INVALIDPARAMETERVALUE_VPCIDNOTEXIST = 'InvalidParameterValue.VpcIdNotExist'
 
+# 指定的VpcId和SubnetId不匹配。
+INVALIDPARAMETERVALUE_VPCIDSUBNETIDNOTMATCH = 'InvalidParameterValue.VpcIdSubnetIdNotMatch'
+
 # VPC网络与实例不在同一可用区
 INVALIDPARAMETERVALUE_VPCIDZONEIDNOTMATCH = 'InvalidParameterValue.VpcIdZoneIdNotMatch'
 
@@ -629,6 +689,9 @@ INVALIDZONE_MISMATCHREGION = 'InvalidZone.MismatchRegion'
 # 一个实例绑定安全组数量不能超过5个
 LIMITEXCEEDED_ASSOCIATEUSGLIMITEXCEEDED = 'LimitExceeded.AssociateUSGLimitExceeded'
 
+# 已达到可购买实例的配额上限。
+LIMITEXCEEDED_CVMINSTANCEQUOTA = 'LimitExceeded.CvmInstanceQuota'
+
 # 安全组关联云主机弹性网卡配额超限。
 LIMITEXCEEDED_CVMSVIFSPERSECGROUPLIMITEXCEEDED = 'LimitExceeded.CvmsVifsPerSecGroupLimitExceeded'
 
@@ -722,6 +785,9 @@ OPERATIONDENIED_INNERUSERPROHIBITACTION = 'OperationDenied.InnerUserProhibitActi
 # 实例正在执行其他操作，请稍后再试。
 OPERATIONDENIED_INSTANCEOPERATIONINPROGRESS = 'OperationDenied.InstanceOperationInProgress'
 
+# 非带宽上移用户不允许申请边缘可用区外网IP。
+OPERATIONDENIED_NOTBANDWIDTHSHIFTUPUSERAPPLYEDGEZONEEIP = 'OperationDenied.NotBandwidthShiftUpUserApplyEdgeZoneEip'
+
 # 镜像共享超过配额。
 OVERQUOTA = 'OverQuota'
 
@@ -824,9 +890,18 @@ UNKNOWNPARAMETER = 'UnknownParameter'
 # 操作不支持。
 UNSUPPORTEDOPERATION = 'UnsupportedOperation'
 
+# 该操作暂不支持Arm机器。
+UNSUPPORTEDOPERATION_ARMARCHITECTURE = 'UnsupportedOperation.ArmArchitecture'
+
 # 指定的实例付费模式或者网络付费模式不支持共享带宽包
 UNSUPPORTEDOPERATION_BANDWIDTHPACKAGEIDNOTSUPPORTED = 'UnsupportedOperation.BandwidthPackageIdNotSupported'
 
+# cbs远端ssd盘不支持该操作
+UNSUPPORTEDOPERATION_CBSREMOTESSDNOTSUPPORT = 'UnsupportedOperation.CbsRemoteSsdNotSupport'
+
+# 实例使用商业镜像暂不支持调整付费模式。
+UNSUPPORTEDOPERATION_COMMERCIALIMAGECHANGECHARGETYPE = 'UnsupportedOperation.CommercialImageChangeChargeType'
+
 # 实例创建快照的时间距今不到24小时。
 UNSUPPORTEDOPERATION_DISKSNAPCREATETIMETOOOLD = 'UnsupportedOperation.DiskSnapCreateTimeTooOld'
 
@@ -863,9 +938,15 @@ UNSUPPORTEDOPERATION_INSTANCECHARGETYPE = 'UnsupportedOperation.InstanceChargeTy
 # 不支持混合付费模式。
 UNSUPPORTEDOPERATION_INSTANCEMIXEDPRICINGMODEL = 'UnsupportedOperation.InstanceMixedPricingModel'
 
+# 不支持混合升配和降配实例。
+UNSUPPORTEDOPERATION_INSTANCEMIXEDRESETINSTANCETYPE = 'UnsupportedOperation.InstanceMixedResetInstanceType'
+
 # 中心可用区和边缘可用区实例不能混用批量操作。
 UNSUPPORTEDOPERATION_INSTANCEMIXEDZONETYPE = 'UnsupportedOperation.InstanceMixedZoneType'
 
+# 指定实例不支持操作系统转换。
+UNSUPPORTEDOPERATION_INSTANCEOSCONVERTOSNOTSUPPORT = 'UnsupportedOperation.InstanceOsConvertOsNotSupport'
+
 # 请求不支持操作系统为`Xserver windows2012cndatacenterx86_64`的实例`ins-xxxxxx` 。
 UNSUPPORTEDOPERATION_INSTANCEOSWINDOWS = 'UnsupportedOperation.InstanceOsWindows'
 
@@ -899,6 +980,9 @@ UNSUPPORTEDOPERATION_INSTANCESTATEISOLATING = 'UnsupportedOperation.InstanceStat
 # 不支持操作创建失败的实例。
 UNSUPPORTEDOPERATION_INSTANCESTATELAUNCHFAILED = 'UnsupportedOperation.InstanceStateLaunchFailed'
 
+# 指定操作不支持非运行中状态的实例。
+UNSUPPORTEDOPERATION_INSTANCESTATENOTRUNNING = 'UnsupportedOperation.InstanceStateNotRunning'
+
 # 请求不支持创建未完成的实例
 UNSUPPORTEDOPERATION_INSTANCESTATEPENDING = 'UnsupportedOperation.InstanceStatePending'
 
@@ -932,6 +1016,21 @@ UNSUPPORTEDOPERATION_INSTANCESTATETERMINATED = 'UnsupportedOperation.InstanceSta
 # 请求不支持正在销毁的实例
 UNSUPPORTEDOPERATION_INSTANCESTATETERMINATING = 'UnsupportedOperation.InstanceStateTerminating'
 
+# 实例类型不支持设置`Confidentiality` 状态
+UNSUPPORTEDOPERATION_INSTANCETYPENOTSUPPORTCONFIDENTIALITY = 'UnsupportedOperation.InstanceTypeNotSupportConfidentiality'
+
+# 实例类型不支持设置`GridDriverService` 状态
+UNSUPPORTEDOPERATION_INSTANCETYPENOTSUPPORTGRIDLICENCE = 'UnsupportedOperation.InstanceTypeNotSupportGridLicence'
+
+# 实例类型不支持设置 HighDensityMode 状态
+UNSUPPORTEDOPERATION_INSTANCETYPENOTSUPPORTHIGHDENSITYMODESETTING = 'UnsupportedOperation.InstanceTypeNotSupportHighDensityModeSetting'
+
+# 实例类型不支持设置`EnableJumboFrame` 状态
+UNSUPPORTEDOPERATION_INSTANCETYPENOTSUPPORTJUMBOFRAME = 'UnsupportedOperation.InstanceTypeNotSupportJumboFrame'
+
+# 不支持不重启情况下修改Jumbo Frame状态
+UNSUPPORTEDOPERATION_INSTANCESENABLEJUMBOWITHOUTREBOOT = 'UnsupportedOperation.InstancesEnableJumboWithoutReboot'
+
 # 不支持已启用销毁保护的实例，请先到设置实例销毁保护，关闭实例销毁保护，然后重试。
 UNSUPPORTEDOPERATION_INSTANCESPROTECTED = 'UnsupportedOperation.InstancesProtected'
 
@@ -983,6 +1082,9 @@ UNSUPPORTEDOPERATION_LOCALDISKMIGRATINGTOCLOUDDISK = 'UnsupportedOperation.Local
 # 此请求不支持该区域镜像,请更换其他镜像。
 UNSUPPORTEDOPERATION_LOCATIONIMAGENOTSUPPORTED = 'UnsupportedOperation.LocationImageNotSupported'
 
+# 市场镜像实例不支持操作系统转换
+UNSUPPORTEDOPERATION_MARKETIMAGECONVERTOSUNSUPPORTED = 'UnsupportedOperation.MarketImageConvertOSUnsupported'
+
 # 从市场镜像创建的自定义镜像不支持导出。
 UNSUPPORTEDOPERATION_MARKETIMAGEEXPORTUNSUPPORTED = 'UnsupportedOperation.MarketImageExportUnsupported'
 
@@ -1061,9 +1163,15 @@ UNSUPPORTEDOPERATION_STOPPEDMODESTOPCHARGING = 'UnsupportedOperation.StoppedMode
 # 不支持关机不收费机器做同类型变配操作。
 UNSUPPORTEDOPERATION_STOPPEDMODESTOPCHARGINGSAMEFAMILY = 'UnsupportedOperation.StoppedModeStopChargingSameFamily'
 
+# 指定的镜像不支持转为加密自定义镜像。
+UNSUPPORTEDOPERATION_SYNCENCRYPTIMAGENOTSUPPORT = 'UnsupportedOperation.SyncEncryptImageNotSupport'
+
 # 请求不支持该类型系统盘。
 UNSUPPORTEDOPERATION_SYSTEMDISKTYPE = 'UnsupportedOperation.SystemDiskType'
 
+# 自动化助手不在线情况下，不支持该操作。
+UNSUPPORTEDOPERATION_TATAGENTNOTONLINE = 'UnsupportedOperation.TatAgentNotOnline'
+
 # 包月转包销，不支持包销折扣高于现有包年包月折扣。
 UNSUPPORTEDOPERATION_UNDERWRITEDISCOUNTGREATERTHANPREPAIDDISCOUNT = 'UnsupportedOperation.UnderwriteDiscountGreaterThanPrepaidDiscount'
 
@@ -1088,6 +1196,9 @@ UNSUPPORTEDOPERATION_UNSUPPORTEDINTERNATIONALUSER = 'UnsupportedOperation.Unsupp
 # 指定的Pool非法。
 UNSUPPORTEDOPERATION_UNSUPPORTEDPOOL = 'UnsupportedOperation.UnsupportedPool'
 
+# 指定用户不支持执行操作系统转换。
+UNSUPPORTEDOPERATION_USERCONVERTOSNOTSUPPORT = 'UnsupportedOperation.UserConvertOsNotSupport'
+
 # 用户限额操作的配额不足。
 UNSUPPORTEDOPERATION_USERLIMITOPERATIONEXCEEDQUOTA = 'UnsupportedOperation.UserLimitOperationExceedQuota'
 
