@@ -1,5 +1,5 @@
 # -*- coding: utf8 -*-
-# Copyright (c) 2017-2021 THL A29 Limited, a Tencent company. All Rights Reserved.
+# Copyright (c) 2017-2025 Tencent. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -134,6 +134,9 @@ INVALIDPARAMETERVALUE_JSONHASINVALIDNODE = 'InvalidParameterValue.JSONHasInvalid
 # State JSON对象超过大小限制，最大为 8k。
 INVALIDPARAMETERVALUE_JSONSIZEEXCEEDLIMIT = 'InvalidParameterValue.JSONSizeExceedLimit'
 
+# 不可合并。
+INVALIDPARAMETERVALUE_NOTMERGEABLE = 'InvalidParameterValue.NotMergeAble'
+
 # 修改规则的操作被禁止。
 INVALIDPARAMETERVALUE_OPERATIONDENIED = 'InvalidParameterValue.OperationDenied'
 
