@@ -693,7 +693,7 @@ class LkeapClient(AbstractClient):
 
 
     def RunRerank(self, request):
-        """基于知识引擎精调模型技术的rerank模型，支持对多路召回的结果进行重排序，根据query与切片内容的相关性，按分数由高到低对切片进行排序，并输出对应的打分结果。
+        """基于知识引擎精调模型技术的rerank模型，支持对多路召回的结果进行重排序，根据query与切片内容的相关性，按照顺序给出每一条结果和query的相关性分数。
 
         :param request: Request instance for RunRerank.
         :type request: :class:`tencentcloud.lkeap.v20240522.models.RunRerankRequest`
