@@ -834,6 +834,29 @@ class MariadbClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def DescribeInstanceSSLAttributes(self, request):
+        """本接口（DescribeInstanceSSLAttributes）用于拉取实例SSL认证属性
+
+        :param request: Request instance for DescribeInstanceSSLAttributes.
+        :type request: :class:`tencentcloud.mariadb.v20170312.models.DescribeInstanceSSLAttributesRequest`
+        :rtype: :class:`tencentcloud.mariadb.v20170312.models.DescribeInstanceSSLAttributesResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribeInstanceSSLAttributes", params, headers=headers)
+            response = json.loads(body)
+            model = models.DescribeInstanceSSLAttributesResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def DescribeLogFileRetentionPeriod(self, request):
         """本接口(DescribeLogFileRetentionPeriod)用于查看数据库备份日志的备份天数的设置情况。
 
@@ -903,6 +926,32 @@ class MariadbClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def DescribeProcessList(self, request):
+        """本接口 (DescribeProcessList) 用于查询当前正在运行的线程（连接/查询）信息。
+
+        - 可以根据客户端IP，DB，执行时间等信息来查询实例正在运行的线程信息。过滤信息详细请见过滤器Filter。
+        - 如果参数为空，返回当前用户一定数量（Limit所指定的数量，默认为20）的线程信息。
+
+        :param request: Request instance for DescribeProcessList.
+        :type request: :class:`tencentcloud.mariadb.v20170312.models.DescribeProcessListRequest`
+        :rtype: :class:`tencentcloud.mariadb.v20170312.models.DescribeProcessListResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribeProcessList", params, headers=headers)
+            response = json.loads(body)
+            model = models.DescribeProcessListResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def DescribeProjectSecurityGroups(self, request):
         """本接口（DescribeProjectSecurityGroups）用于查询项目安全组信息
 
@@ -1487,6 +1536,52 @@ class MariadbClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def ModifyInstanceProtectedProperty(self, request):
+        """该接口用于对实例修改删除保护属性
+
+        :param request: Request instance for ModifyInstanceProtectedProperty.
+        :type request: :class:`tencentcloud.mariadb.v20170312.models.ModifyInstanceProtectedPropertyRequest`
+        :rtype: :class:`tencentcloud.mariadb.v20170312.models.ModifyInstanceProtectedPropertyResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("ModifyInstanceProtectedProperty", params, headers=headers)
+            response = json.loads(body)
+            model = models.ModifyInstanceProtectedPropertyResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
+    def ModifyInstanceSSLAttributes(self, request):
+        """本接口  （ModifyInstanceSSLAttributes）用于修改实例SSL认证功能属性
+
+        :param request: Request instance for ModifyInstanceSSLAttributes.
+        :type request: :class:`tencentcloud.mariadb.v20170312.models.ModifyInstanceSSLAttributesRequest`
+        :rtype: :class:`tencentcloud.mariadb.v20170312.models.ModifyInstanceSSLAttributesResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("ModifyInstanceSSLAttributes", params, headers=headers)
+            response = json.loads(body)
+            model = models.ModifyInstanceSSLAttributesResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def ModifyInstanceVip(self, request):
         """本接口（ModifyInstanceVip）用于修改实例VIP
 
