@@ -1,5 +1,5 @@
 # -*- coding: utf8 -*-
-# Copyright (c) 2017-2021 THL A29 Limited, a Tencent company. All Rights Reserved.
+# Copyright (c) 2017-2025 Tencent. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -20,6 +20,9 @@ AUTHFAILURE = 'AuthFailure'
 # 操作失败。
 FAILEDOPERATION = 'FailedOperation'
 
+# 实例开启了销毁保护，不允许销毁
+FAILEDOPERATION_DELETIONPROTECTIONENABLED = 'FailedOperation.DeletionProtectionEnabled'
+
 # 按key回档未开启
 FAILEDOPERATION_FLASHBACKBYKEYNOTOPEN = 'FailedOperation.FlashbackByKeyNotOpen'
 
