@@ -1,5 +1,5 @@
 # -*- coding: utf8 -*-
-# Copyright (c) 2017-2021 THL A29 Limited, a Tencent company. All Rights Reserved.
+# Copyright (c) 2017-2025 Tencent. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -49,6 +49,52 @@ class SesClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def CreateAddressUnsubscribeConfig(self, request):
+        """创建地址级退订配置
+
+        :param request: Request instance for CreateAddressUnsubscribeConfig.
+        :type request: :class:`tencentcloud.ses.v20201002.models.CreateAddressUnsubscribeConfigRequest`
+        :rtype: :class:`tencentcloud.ses.v20201002.models.CreateAddressUnsubscribeConfigResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("CreateAddressUnsubscribeConfig", params, headers=headers)
+            response = json.loads(body)
+            model = models.CreateAddressUnsubscribeConfigResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
+    def CreateCustomBlacklist(self, request):
+        """添加自定义黑名单
+
+        :param request: Request instance for CreateCustomBlacklist.
+        :type request: :class:`tencentcloud.ses.v20201002.models.CreateCustomBlacklistRequest`
+        :rtype: :class:`tencentcloud.ses.v20201002.models.CreateCustomBlacklistResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("CreateCustomBlacklist", params, headers=headers)
+            response = json.loads(body)
+            model = models.CreateCustomBlacklistResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def CreateEmailAddress(self, request):
         """在验证了发信域名之后，您需要一个发信地址来发送邮件。例如发信域名是mail.qcloud.com，那么发信地址可以为 service@mail.qcloud.com。如果您想要收件人在收件箱列表中显示您的别名，例如"腾讯云邮件通知"。那么发信地址为： 别名 空格 尖括号 邮箱地址。请注意中间需要有空格
 
@@ -188,6 +234,29 @@ class SesClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def DeleteAddressUnsubscribeConfig(self, request):
+        """删除地址级退订配置
+
+        :param request: Request instance for DeleteAddressUnsubscribeConfig.
+        :type request: :class:`tencentcloud.ses.v20201002.models.DeleteAddressUnsubscribeConfigRequest`
+        :rtype: :class:`tencentcloud.ses.v20201002.models.DeleteAddressUnsubscribeConfigResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DeleteAddressUnsubscribeConfig", params, headers=headers)
+            response = json.loads(body)
+            model = models.DeleteAddressUnsubscribeConfigResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def DeleteBlackList(self, request):
         """邮箱被拉黑之后，用户如果确认收件邮箱有效或者已经处于激活状态，可以从腾讯云地址库中删除该黑名单之后继续投递。
 
@@ -211,6 +280,29 @@ class SesClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def DeleteCustomBlackList(self, request):
+        """删除自定义黑名单邮箱地址
+
+        :param request: Request instance for DeleteCustomBlackList.
+        :type request: :class:`tencentcloud.ses.v20201002.models.DeleteCustomBlackListRequest`
+        :rtype: :class:`tencentcloud.ses.v20201002.models.DeleteCustomBlackListResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DeleteCustomBlackList", params, headers=headers)
+            response = json.loads(body)
+            model = models.DeleteCustomBlackListResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def DeleteEmailAddress(self, request):
         """删除发信人地址
 
@@ -395,6 +487,29 @@ class SesClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def ListAddressUnsubscribeConfig(self, request):
+        """获取地址级退订配置列表
+
+        :param request: Request instance for ListAddressUnsubscribeConfig.
+        :type request: :class:`tencentcloud.ses.v20201002.models.ListAddressUnsubscribeConfigRequest`
+        :rtype: :class:`tencentcloud.ses.v20201002.models.ListAddressUnsubscribeConfigResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("ListAddressUnsubscribeConfig", params, headers=headers)
+            response = json.loads(body)
+            model = models.ListAddressUnsubscribeConfigResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def ListBlackEmailAddress(self, request):
         """腾讯云发送的邮件一旦被收件方判断为硬退(Hard Bounce)，腾讯云会拉黑该地址，并不允许所有用户向该地址发送邮件。成为邮箱黑名单。如果业务方确认是误判，可以从黑名单中删除。
 
@@ -418,6 +533,29 @@ class SesClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def ListCustomBlacklist(self, request):
+        """获取自定义黑名单列表
+
+        :param request: Request instance for ListCustomBlacklist.
+        :type request: :class:`tencentcloud.ses.v20201002.models.ListCustomBlacklistRequest`
+        :rtype: :class:`tencentcloud.ses.v20201002.models.ListCustomBlacklistResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("ListCustomBlacklist", params, headers=headers)
+            response = json.loads(body)
+            model = models.ListCustomBlacklistResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def ListEmailAddress(self, request):
         """获取发信地址列表
 
@@ -579,6 +717,52 @@ class SesClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def UpdateAddressUnsubscribeConfig(self, request):
+        """用于更新地址级退订配置
+
+        :param request: Request instance for UpdateAddressUnsubscribeConfig.
+        :type request: :class:`tencentcloud.ses.v20201002.models.UpdateAddressUnsubscribeConfigRequest`
+        :rtype: :class:`tencentcloud.ses.v20201002.models.UpdateAddressUnsubscribeConfigResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("UpdateAddressUnsubscribeConfig", params, headers=headers)
+            response = json.loads(body)
+            model = models.UpdateAddressUnsubscribeConfigResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
+    def UpdateCustomBlackList(self, request):
+        """更新自定义黑名单
+
+        :param request: Request instance for UpdateCustomBlackList.
+        :type request: :class:`tencentcloud.ses.v20201002.models.UpdateCustomBlackListRequest`
+        :rtype: :class:`tencentcloud.ses.v20201002.models.UpdateCustomBlackListResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("UpdateCustomBlackList", params, headers=headers)
+            response = json.loads(body)
+            model = models.UpdateCustomBlackListResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def UpdateEmailIdentity(self, request):
         """您已经成功配置好了您的DNS，接下来请求腾讯云验证您的DNS配置是否正确
 
