@@ -1,5 +1,5 @@
 # -*- coding: utf8 -*-
-# Copyright (c) 2017-2021 THL A29 Limited, a Tencent company. All Rights Reserved.
+# Copyright (c) 2017-2025 Tencent. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -29,6 +29,9 @@ class TioneClient(AbstractClient):
     def ChatCompletion(self, request):
         """该接口支持与自行部署的大模型的聊天。
 
+        使用该接口调用时需要携带腾讯云的密钥信息用于身份信息鉴权，建议通过腾讯云的云 API SDK调用，具体可以参考
+        https://cloud.tencent.com/document/product/1278/85305
+
         :param request: Request instance for ChatCompletion.
         :type request: :class:`tencentcloud.tione.v20211111.models.ChatCompletionRequest`
         :rtype: :class:`tencentcloud.tione.v20211111.models.ChatCompletionResponse`
@@ -95,6 +98,29 @@ class TioneClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def CreateModelServiceAuthToken(self, request):
+        """创建一个 AuthToken
+
+        :param request: Request instance for CreateModelServiceAuthToken.
+        :type request: :class:`tencentcloud.tione.v20211111.models.CreateModelServiceAuthTokenRequest`
+        :rtype: :class:`tencentcloud.tione.v20211111.models.CreateModelServiceAuthTokenResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("CreateModelServiceAuthToken", params, headers=headers)
+            response = json.loads(body)
+            model = models.CreateModelServiceAuthTokenResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def CreateNotebook(self, request):
         """创建Notebook
 
@@ -164,6 +190,29 @@ class TioneClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def CreateTrainingTask(self, request):
+        """创建模型训练任务
+
+        :param request: Request instance for CreateTrainingTask.
+        :type request: :class:`tencentcloud.tione.v20211111.models.CreateTrainingTaskRequest`
+        :rtype: :class:`tencentcloud.tione.v20211111.models.CreateTrainingTaskResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("CreateTrainingTask", params, headers=headers)
+            response = json.loads(body)
+            model = models.CreateTrainingTaskResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def DeleteDataset(self, request):
         """删除数据集
 
@@ -210,6 +259,29 @@ class TioneClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def DeleteModelServiceAuthToken(self, request):
+        """删除一个 AuthToken
+
+        :param request: Request instance for DeleteModelServiceAuthToken.
+        :type request: :class:`tencentcloud.tione.v20211111.models.DeleteModelServiceAuthTokenRequest`
+        :rtype: :class:`tencentcloud.tione.v20211111.models.DeleteModelServiceAuthTokenResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DeleteModelServiceAuthToken", params, headers=headers)
+            response = json.loads(body)
+            model = models.DeleteModelServiceAuthTokenResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def DeleteModelServiceGroup(self, request):
         """根据服务组id删除服务组下所有模型服务
 
@@ -302,6 +374,29 @@ class TioneClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def DeleteTrainingTask(self, request):
+        """删除训练任务
+
+        :param request: Request instance for DeleteTrainingTask.
+        :type request: :class:`tencentcloud.tione.v20211111.models.DeleteTrainingTaskRequest`
+        :rtype: :class:`tencentcloud.tione.v20211111.models.DeleteTrainingTaskResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DeleteTrainingTask", params, headers=headers)
+            response = json.loads(body)
+            model = models.DeleteTrainingTaskResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def DescribeBillingResourceGroup(self, request):
         """查询资源组节点列表
 
@@ -463,8 +558,33 @@ class TioneClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def DescribeEvents(self, request):
+        """获取任务式建模训练任务，Notebook，在线服务和批量预测任务的事件API
+
+        :param request: Request instance for DescribeEvents.
+        :type request: :class:`tencentcloud.tione.v20211111.models.DescribeEventsRequest`
+        :rtype: :class:`tencentcloud.tione.v20211111.models.DescribeEventsResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribeEvents", params, headers=headers)
+            response = json.loads(body)
+            model = models.DescribeEventsResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def DescribeInferTemplates(self, request):
-        """查询推理镜像模板
+        """已废弃，收敛到统一接口
+
+        查询推理镜像模板
 
         :param request: Request instance for DescribeInferTemplates.
         :type request: :class:`tencentcloud.tione.v20211111.models.DescribeInferTemplatesRequest`
@@ -486,6 +606,29 @@ class TioneClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def DescribeLogs(self, request):
+        """获取任务式建模训练任务，Notebook，在线服务和批量预测任务的日志API
+
+        :param request: Request instance for DescribeLogs.
+        :type request: :class:`tencentcloud.tione.v20211111.models.DescribeLogsRequest`
+        :rtype: :class:`tencentcloud.tione.v20211111.models.DescribeLogsResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribeLogs", params, headers=headers)
+            response = json.loads(body)
+            model = models.DescribeLogsResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def DescribeModelAccelerateTask(self, request):
         """查询模型优化任务详情
 
@@ -693,6 +836,29 @@ class TioneClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def DescribePlatformImages(self, request):
+        """查询平台镜像信息
+
+        :param request: Request instance for DescribePlatformImages.
+        :type request: :class:`tencentcloud.tione.v20211111.models.DescribePlatformImagesRequest`
+        :rtype: :class:`tencentcloud.tione.v20211111.models.DescribePlatformImagesResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribePlatformImages", params, headers=headers)
+            response = json.loads(body)
+            model = models.DescribePlatformImagesResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def DescribeTrainingModelVersion(self, request):
         """查询模型版本
 
@@ -831,6 +997,75 @@ class TioneClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def ModifyModelServiceAuthToken(self, request):
+        """修改一个 AuthToken
+
+        :param request: Request instance for ModifyModelServiceAuthToken.
+        :type request: :class:`tencentcloud.tione.v20211111.models.ModifyModelServiceAuthTokenRequest`
+        :rtype: :class:`tencentcloud.tione.v20211111.models.ModifyModelServiceAuthTokenResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("ModifyModelServiceAuthToken", params, headers=headers)
+            response = json.loads(body)
+            model = models.ModifyModelServiceAuthTokenResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
+    def ModifyModelServiceAuthorization(self, request):
+        """修改服务鉴权配置
+
+        :param request: Request instance for ModifyModelServiceAuthorization.
+        :type request: :class:`tencentcloud.tione.v20211111.models.ModifyModelServiceAuthorizationRequest`
+        :rtype: :class:`tencentcloud.tione.v20211111.models.ModifyModelServiceAuthorizationResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("ModifyModelServiceAuthorization", params, headers=headers)
+            response = json.loads(body)
+            model = models.ModifyModelServiceAuthorizationResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
+    def ModifyNotebookTags(self, request):
+        """修改Notebook标签
+
+        :param request: Request instance for ModifyNotebookTags.
+        :type request: :class:`tencentcloud.tione.v20211111.models.ModifyNotebookTagsRequest`
+        :rtype: :class:`tencentcloud.tione.v20211111.models.ModifyNotebookTagsResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("ModifyNotebookTags", params, headers=headers)
+            response = json.loads(body)
+            model = models.ModifyNotebookTagsResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def PushTrainingMetrics(self, request):
         """上报训练自定义指标
 
@@ -877,6 +1112,29 @@ class TioneClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def StartTrainingTask(self, request):
+        """启动模型训练任务
+
+        :param request: Request instance for StartTrainingTask.
+        :type request: :class:`tencentcloud.tione.v20211111.models.StartTrainingTaskRequest`
+        :rtype: :class:`tencentcloud.tione.v20211111.models.StartTrainingTaskResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("StartTrainingTask", params, headers=headers)
+            response = json.loads(body)
+            model = models.StartTrainingTaskResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def StopModelAccelerateTask(self, request):
         """停止模型加速任务
 
@@ -916,6 +1174,29 @@ class TioneClient(AbstractClient):
             model = models.StopNotebookResponse()
             model._deserialize(response["Response"])
             return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
+    def StopTrainingTask(self, request):
+        """停止模型训练任务
+
+        :param request: Request instance for StopTrainingTask.
+        :type request: :class:`tencentcloud.tione.v20211111.models.StopTrainingTaskRequest`
+        :rtype: :class:`tencentcloud.tione.v20211111.models.StopTrainingTaskResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("StopTrainingTask", params, headers=headers)
+            response = json.loads(body)
+            model = models.StopTrainingTaskResponse()
+            model._deserialize(response["Response"])
+            return model
         except Exception as e:
             if isinstance(e, TencentCloudSDKException):
                 raise
